@@ -109,6 +109,12 @@ var (
 			Name: dashboard.ConfigManagedNamespace,
 		},
 	}
+
+	servingNamespace = corev1.Namespace{
+		ObjectMeta: metav1.ObjectMeta{
+			Name: "knative-serving",
+		},
+	}
 )
 
 func init() {
@@ -116,7 +122,7 @@ func init() {
 	os.Setenv("KOURIER_MANIFEST_PATH", "kourier/testdata/kourier-latest.yaml")
 	os.Setenv(quickstart.EnvKey, "../../../deploy/resources/quickstart/serverless-application-quickstart.yaml")
 	os.Setenv(dashboard.ServingResourceDashboardPathEnvVar, "../dashboard/testdata/grafana-dash-knative-serving-resources.yaml")
-
+	os.Setenv("TEST_ROLE_PATH", "../dashboard/testdata/role-service-monitor.yaml")
 	apis.AddToScheme(scheme.Scheme)
 }
 
@@ -155,13 +161,12 @@ func TestKourierReconcile(t *testing.T) {
 			ccd := &consolev1.ConsoleCLIDownload{}
 			ns := &dashboardNamespace
 			knService := &defaultKnService
-			initObjs := []runtime.Object{ks, ingress, ns, knService}
 
-			cl := fake.NewFakeClient(initObjs...)
+			cl := fake.NewClientBuilder().WithObjects(ks, ingress, ns, &servingNamespace, knService).Build()
 			r := &ReconcileKnativeServing{client: cl, scheme: scheme.Scheme}
 
 			// Reconcile to initialize
-			if _, err := r.Reconcile(defaultRequest); err != nil {
+			if _, err := r.Reconcile(context.Background(), defaultRequest); err != nil {
 				t.Fatalf("reconcile: (%v)", err)
 			}
 
@@ -207,7 +212,7 @@ func TestKourierReconcile(t *testing.T) {
 			req := reconcile.Request{
 				NamespacedName: types.NamespacedName{Namespace: test.ownerNamespace, Name: test.ownerName},
 			}
-			if _, err := r.Reconcile(req); err != nil {
+			if _, err := r.Reconcile(context.Background(), req); err != nil {
 				t.Fatalf("reconcile: (%v)", err)
 			}
 
@@ -281,13 +286,13 @@ func TestCustomCertsConfigMap(t *testing.T) {
 		in: []runtime.Object{
 			ctrl("2"),
 			cm("test-cm", nil, serviceCAAnnotations, nil, "3"),
-			cm("test-cm-service-ca", nil, serviceCAAnnotations, nil, ""),
-			cm("test-cm-trusted-ca", trustedCALabels, nil, map[string]string{"trustedCA": "baz"}, ""),
+			cm("test-cm-service-ca", nil, serviceCAAnnotations, nil, "1"),
+			cm("test-cm-trusted-ca", trustedCALabels, nil, map[string]string{"trustedCA": "baz"}, "1"),
 		},
 		out: []*corev1.ConfigMap{
 			cm("test-cm", nil, nil, map[string]string{"trustedCA": "baz"}, "4"),
-			cm("test-cm-service-ca", nil, serviceCAAnnotations, nil, ""),
-			cm("test-cm-trusted-ca", trustedCALabels, nil, map[string]string{"trustedCA": "baz"}, ""),
+			cm("test-cm-service-ca", nil, serviceCAAnnotations, nil, "1"),
+			cm("test-cm-trusted-ca", trustedCALabels, nil, map[string]string{"trustedCA": "baz"}, "1"),
 		},
 		outCtrl: ctrl("4"),
 	}, {
@@ -295,13 +300,13 @@ func TestCustomCertsConfigMap(t *testing.T) {
 		in: []runtime.Object{
 			ctrl("0"),
 			cm("test-cm", nil, serviceCAAnnotations, nil, "1"),
-			cm("test-cm-service-ca", nil, serviceCAAnnotations, map[string]string{"serviceCA": "bar"}, ""),
-			cm("test-cm-trusted-ca", trustedCALabels, nil, map[string]string{"trustedCA": "baz"}, ""),
+			cm("test-cm-service-ca", nil, serviceCAAnnotations, map[string]string{"serviceCA": "bar"}, "1"),
+			cm("test-cm-trusted-ca", trustedCALabels, nil, map[string]string{"trustedCA": "baz"}, "1"),
 		},
 		out: []*corev1.ConfigMap{
 			cm("test-cm", nil, nil, map[string]string{"serviceCA": "bar", "trustedCA": "baz"}, "2"),
-			cm("test-cm-service-ca", nil, serviceCAAnnotations, map[string]string{"serviceCA": "bar"}, ""),
-			cm("test-cm-trusted-ca", trustedCALabels, nil, map[string]string{"trustedCA": "baz"}, ""),
+			cm("test-cm-service-ca", nil, serviceCAAnnotations, map[string]string{"serviceCA": "bar"}, "1"),
+			cm("test-cm-trusted-ca", trustedCALabels, nil, map[string]string{"trustedCA": "baz"}, "1"),
 		},
 		outCtrl: ctrl("2"),
 	}, {
@@ -309,20 +314,24 @@ func TestCustomCertsConfigMap(t *testing.T) {
 		in: []runtime.Object{
 			ctrl("10"),
 			cm("test-cm", nil, serviceCAAnnotations, map[string]string{"serviceCA": "bar", "trustedCA": "baz"}, "100"),
-			cm("test-cm-service-ca", nil, serviceCAAnnotations, map[string]string{"serviceCA": "bar"}, ""),
-			cm("test-cm-trusted-ca", trustedCALabels, nil, map[string]string{"trustedCA": "baz2"}, ""),
+			cm("test-cm-service-ca", nil, serviceCAAnnotations, map[string]string{"serviceCA": "bar"}, "1"),
+			cm("test-cm-trusted-ca", trustedCALabels, nil, map[string]string{"trustedCA": "baz2"}, "1"),
 		},
 		out: []*corev1.ConfigMap{
 			cm("test-cm", nil, nil, map[string]string{"serviceCA": "bar", "trustedCA": "baz2"}, "101"),
-			cm("test-cm-service-ca", nil, serviceCAAnnotations, map[string]string{"serviceCA": "bar"}, ""),
-			cm("test-cm-trusted-ca", trustedCALabels, nil, map[string]string{"trustedCA": "baz2"}, ""),
+			cm("test-cm-service-ca", nil, serviceCAAnnotations, map[string]string{"serviceCA": "bar"}, "1"),
+			cm("test-cm-trusted-ca", trustedCALabels, nil, map[string]string{"trustedCA": "baz2"}, "1"),
 		},
 		outCtrl: ctrl("101"),
 	}}
 
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			cl := fake.NewFakeClient(test.in...)
+			cl := fake.NewClientBuilder().
+				WithObjects(&servingNamespace).
+				WithRuntimeObjects(test.in...).
+				Build()
+
 			r := &ReconcileKnativeServing{client: cl, scheme: scheme.Scheme}
 
 			if err := r.ensureCustomCertsConfigMap(ks); err != nil {
@@ -362,18 +371,15 @@ func TestCustomCertsConfigMap(t *testing.T) {
 
 // TestKnativeServingStatus tests KnativeServing CR status with Kourier's installation failure.
 func TestKnativeServingStatus(t *testing.T) {
-	ks := &defaultKnativeServing
-	ingress := &defaultIngress
-	knService := &defaultKnService
+	cl := fake.NewClientBuilder().
+		WithObjects(&defaultKnativeServing, &defaultIngress, &defaultKnService, &servingNamespace).
+		Build()
 
-	initObjs := []runtime.Object{ks, ingress, knService}
-
-	cl := fake.NewFakeClient(initObjs...)
 	r := &ReconcileKnativeServing{client: cl, scheme: scheme.Scheme}
 
 	// Test with invalid Kourier manifest file.
 	os.Setenv("KOURIER_MANIFEST_PATH", "kourier/testdata/non-exist-file")
-	if _, err := r.Reconcile(defaultRequest); err == nil {
+	if _, err := r.Reconcile(context.Background(), defaultRequest); err == nil {
 		t.Fatalf("reconcile does not fail with invalid manifest path")
 	}
 
@@ -388,7 +394,7 @@ func TestKnativeServingStatus(t *testing.T) {
 
 	// Reconcile with correct Kourier manifest file.
 	os.Setenv("KOURIER_MANIFEST_PATH", "kourier/testdata/kourier-latest.yaml")
-	if _, err := r.Reconcile(defaultRequest); err != nil {
+	if _, err := r.Reconcile(context.Background(), defaultRequest); err != nil {
 		t.Fatalf("reconcile: (%v)", err)
 	}
 	successKs := &v1alpha1.KnativeServing{}
