@@ -2,6 +2,7 @@ package eventing
 
 import (
 	"context"
+	"fmt"
 	"os"
 
 	mf "github.com/manifestival/manifestival"
@@ -9,8 +10,11 @@ import (
 	"k8s.io/apimachinery/pkg/api/resource"
 	"knative.dev/operator/pkg/apis/operator/v1alpha1"
 	operator "knative.dev/operator/pkg/reconciler/common"
+	"knative.dev/pkg/controller"
 )
 
+const requiredNsEnvName = "REQUIRED_EVENTING_NAMESPACE"
+
 // NewExtension creates a new extension for a Knative Eventing controller.
 func NewExtension(ctx context.Context) operator.Extension {
 	return &extension{}
@@ -18,6 +22,10 @@ func NewExtension(ctx context.Context) operator.Extension {
 
 type extension struct{}
 
+func (e *extension) Manifests(v1alpha1.KComponent) ([]mf.Manifest, error) {
+	return nil, nil
+}
+
 func (e *extension) Transformers(v1alpha1.KComponent) []mf.Transformer {
 	return nil
 }
@@ -25,6 +33,12 @@ func (e *extension) Transformers(v1alpha1.KComponent) []mf.Transformer {
 func (e *extension) Reconcile(ctx context.Context, comp v1alpha1.KComponent) error {
 	ke := comp.(*v1alpha1.KnativeEventing)
 
+	requiredNs := os.Getenv(requiredNsEnvName)
+	if requiredNs != "" && ke.Namespace != requiredNs {
+		ke.Status.MarkInstallFailed(fmt.Sprintf("Knative Eventing must be installed into the namespace %q", requiredNs))
+		return controller.NewPermanentError(fmt.Errorf("deployed Knative Serving into unsupported namespace %q", ke.Namespace))
+	}
+
 	// Override images.
 	// TODO(SRVCOM-1069): Rethink overriding behavior and/or error surfacing.
 	images := common.ImageMapFromEnvironment(os.Environ())
